package App::ArticleWrap;

our $VERSION = 1.01;

=head1 NAME

App::ArticleWrap - word wrap news articles or mail files

=head1 DESCRIPTION

This is a stub module, see F<script/article-wrap> for details of the app.

=head1 AUTHOR

Alex Schroeder

=head1 LICENSE

GNU Affero General Public License

=cut

1;
